# phenology
This is a simple package designed for phenological analysis, currently offering only one functionality: calculating the optimal pre-season length. Subsequent developments will include additional features such as extracting vegetation phenophases.
You can see more details from https://github.com/spjace/phenology/
